Learn R Programming

ProfileGLMM (version 1.1.0)

predict.pglmm_fit: Prediction of cluster memberships and outcomes

Description

(This documentation is now for internal use only)

Usage

# S3 method for pglmm_fit
predict(object, newData, ...)

Arguments

object

An object of class pglmm_fit .

newData

: A list with fields

  • XFE A numeric matrix of fixed effects covariates for the prediction data.

  • XLat A numeric matrix of latent effect covariates.

  • UCont A numeric matrix or vector of continuous profile variables. Defaults to NULL.

  • UCat A numeric matrix or vector of categorical profile variables. Defaults to NULL.

...

Additional arguments

Examples

Run this code
# Load post_Obj, the result of profileGLMM_postProcess()
data("examp")
post_Obj = examp$post_Obj

# run prediction for training data
pred_Obj = predict(post_Obj,examp$dataProfile$d)


Run the code above in your browser using DataLab