powered by
(This documentation is now for internal use only)
# S3 method for pglmm_fit predict(object, newData, ...)
An object of class pglmm_fit .
pglmm_fit
: A list with fields
XFE A numeric matrix of fixed effects covariates for the prediction data.
XLat A numeric matrix of latent effect covariates.
UCont A numeric matrix or vector of continuous profile variables. Defaults to NULL.
NULL
UCat A numeric matrix or vector of categorical profile variables. Defaults to NULL.
Additional arguments
# Load post_Obj, the result of profileGLMM_postProcess() data("examp") post_Obj = examp$post_Obj # run prediction for training data pred_Obj = predict(post_Obj,examp$dataProfile$d)
Run the code above in your browser using DataLab